==> kadu_0.12.3.orig.tar.bz2: kadu-0.12.3/plugins/cenzor/notify/cenzor-notification.h <==
/*
 * %kadu copyright begin%
 * Copyright 2008, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
 * Copyright 2008 Michał Podsiadlik (michal@kadu.net)
 * Copyright 2009 Bartłomiej Zimoń (uzi18@o2.pl)
 * Copyright 2004 Adrian Smarzewski (adrian@kadu.net)
 * Copyright 2007, 2008, 2009, 2010, 2011 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
 * Copyright 2004, 2006 Marcin Ślusarz (joi@kadu.net)
 * %kadu copyright end%
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef CENZOR_NOTIFICATION_H
#define CENZOR_NOTIFICATION_H

#include "notify/chat-notification.h"

class NotifyEvent;

class CenzorNotification : public ChatNotification
{
	Q_OBJECT

	static NotifyEvent *CenzoredNotification;

public:
	static void registerNotifications();
	static void unregisterNotifiactions();

	static void notifyCenzored(const Chat &chat);

	explicit CenzorNotification(const Chat &chat);
	virtual ~CenzorNotification();

};

#endif // CENZOR_NOTIFICATION_H

==> kadu_1.2.orig.tar.bz2: kadu-1.2/plugins/cenzor/notify/cenzor-notification.h <==
/*
 * %kadu copyright begin%
 * Copyright 2008, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
 * Copyright 2012 Wojciech Treter (juzefwt@gmail.com)
 * Copyright 2008 Michał Podsiadlik (michal@kadu.net)
 * Copyright 2009 Bartłomiej Zimoń (uzi18@o2.pl)
 * Copyright 2004 Adrian Smarzewski (adrian@kadu.net)
 * Copyright 2007, 2008, 2009, 2010, 2011, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
 * Copyright 2004, 2006 Marcin Ślusarz (joi@kadu.net)
 * %kadu copyright end%
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef CENZOR_NOTIFICATION_H
#define CENZOR_NOTIFICATION_H

#include "notify/notification/chat-notification.h"

class NotifyEvent;

class CenzorNotification : public ChatNotification
{
	Q_OBJECT

	static NotifyEvent *CenzoredNotification;

public:
	static void registerNotifications();
	static void unregisterNotifiactions();

	static void notifyCenzored(const Chat &chat);

	explicit CenzorNotification(const Chat &chat);
	virtual ~CenzorNotification();

};

#endif // CENZOR_NOTIFICATION_H
